==> core-react-0.8.0.tgz: package/es/dialog/Dialog.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cx from 'classnames';
import classlist from 'classlist';
import PropTypes from 'prop-types';
import React from 'react';
import ReactDOM, { createPortal } from 'react-dom';
import omit from '../_utils/omit';
import ToggleNode from '../_utils/ToggleNode';
import Backdrop from './Backdrop';


var Dialog = /*#__PURE__*/function (_React$Component) {
  _inherits(Dialog, _React$Component);

  function Dialog(props) {
    var _this;

    _classCallCheck(this, Dialog);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Dialog).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "close", function () {
      _this.setState({
        shouldHideBackdrop: true
      });

      var openedDialog = document.getElementsByClassName("".concat("waui", "-dialog__main_open"))[0];

      _this.backUp();

      if (openedDialog && !_this.props.autoClose) {
        classlist(openedDialog).remove("".concat("waui", "-dialog__main_open"));

        var onTransitionEnd = function onTransitionEnd() {
          openedDialog.style.display = 'none';
          openedDialog.removeEventListener(ToggleNode.END_EVENT, onTransitionEnd);

          _this.props.onClose();
        };

        openedDialog.addEventListener(ToggleNode.END_EVENT, onTransitionEnd);
      } else {
        _this.props.onClose();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "closeBackdropAndAllDialogs", function () {
      if (_this.props.lock) {
        return;
      }

      _this.setState({
        shouldHideBackdrop: true
      });

      var openedDialog = document.getElementsByClassName("".concat("waui", "-dialog__main_open"))[0];

      if (openedDialog) {
        classlist(openedDialog).remove("".concat("waui", "-dialog__main_open"));

        var onTransitionEnd = function onTransitionEnd() {
          openedDialog.style.display = 'none';
          openedDialog.removeEventListener(ToggleNode.END_EVENT, onTransitionEnd);

          _this.props.onClose();
        };

        openedDialog.addEventListener(ToggleNode.END_EVENT, onTransitionEnd);
      } else {
        _this.props.onClose();
      }
    });

    _this.state = {
      shouldHideBackdrop: false,
      hasExistedBackdrop: !!document.getElementsByClassName("".concat("waui", "-dialog__backdrop"))[0]
    };
    _this.containerNode = document.createElement('div');
    document.body.appendChild(_this.containerNode);
    return _this;
  }

  _createClass(Dialog, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        dialog: this
      };
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      if (!this.dialog) {
        return;
      }

      if (!this.dialogInstance) {
        var dialogNode = ReactDOM.findDOMNode(this.dialog);
        this.dialogInstance = new ToggleNode(dialogNode, "".concat("waui", "-dialog__main_open"));
      }

      this.dialogInstance.open();
      this.props.autoClose && window.setTimeout(function () {
        _this2.close();
      }, this.props.duration);
    }
  }, {
    key: "backUp",
    value: function backUp() {
      var dialogStacks = document.getElementsByClassName("".concat("waui", "-dialog__main"));
      var dialogStacksCount = dialogStacks.length;
      dialogStacksCount > 1 && classlist(dialogStacks[dialogStacksCount - 2]).add("".concat("waui", "-dialog__main_open"));
    }
  }, {
    key: "goForward",
    value: function goForward() {
      var dialogStacks = document.getElementsByClassName("".concat("waui", "-dialog__main"));
      var dialogStacksCount = dialogStacks.length;
      dialogStacksCount > 0 && classlist(dialogStacks[dialogStacksCount - 1]).remove("".concat("waui", "-dialog__main_open"));
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      this.goForward();
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.containerNode && document.body.removeChild(this.containerNode);
      this.state.shouldHideBackdrop || this.props.onClose();
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var _this$state = this.state,
          shouldHideBackdrop = _this$state.shouldHideBackdrop,
          hasExistedBackdrop = _this$state.hasExistedBackdrop;

      var _this$props = this.props,
          backdrop = _this$props.backdrop,
          lock = _this$props.lock,
          type = _this$props.type,
          children = _this$props.children,
          other = _objectWithoutProperties(_this$props, ["backdrop", "lock", "type", "children"]);

      var divProps = omit(other, ['lock', 'autoClose']);
      return createPortal(React.createElement("div", _extends({
        ref: function ref(dialog) {
          return _this3.dialog = dialog;
        },
        className: cx("".concat("waui", "-dialog__main"), _defineProperty({}, "".concat("waui", "-dialog__main_").concat(type), type))
      }, divProps), !shouldHideBackdrop && !!backdrop && !hasExistedBackdrop && React.createElement(Backdrop, {
        onClick: this.closeBackdropAndAllDialogs
      }), React.createElement("div", {
        className: "".concat("waui", "-dialog__main-content")
      }, children)), this.containerNode);
    }
  }]);

  return Dialog;
}(React.Component);

_defineProperty(Dialog, "childContextTypes", {
  dialog: PropTypes.instanceOf(Dialog)
});

_defineProperty(Dialog, "propTypes", {
  backdrop: PropTypes.bool,
  lock: PropTypes.bool,
  autoClose: PropTypes.bool,
  duration: PropTypes.number,
  onClose: PropTypes.func,
  type: PropTypes.oneOf(['aside', 'dialog', 'notification', 'modal'])
});

export default Dialog;

==> core-react-0.8.2.tgz: package/es/dialog/Dialog.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cx from 'classnames';
import classlist from 'classlist';
import PropTypes from 'prop-types';
import React from 'react';
import ReactDOM, { createPortal } from 'react-dom';
import omit from '../_utils/omit';
import ToggleNode from '../_utils/ToggleNode';
import Backdrop from './Backdrop';


var Dialog = /*#__PURE__*/function (_React$Component) {
  _inherits(Dialog, _React$Component);

  function Dialog(props) {
    var _this;

    _classCallCheck(this, Dialog);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Dialog).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "close", function () {
      _this.setState({
        shouldHideBackdrop: true
      });

      var openedDialog = document.getElementsByClassName("".concat("waui", "-dialog__main_open"))[0];

      _this.backUp();

      if (openedDialog && !_this.props.autoClose) {
        classlist(openedDialog).remove("".concat("waui", "-dialog__main_open"));

        var onTransitionEnd = function onTransitionEnd() {
          openedDialog.style.display = 'none';
          openedDialog.removeEventListener(ToggleNode.END_EVENT, onTransitionEnd);

          _this.props.onClose();
        };

        openedDialog.addEventListener(ToggleNode.END_EVENT, onTransitionEnd);
      } else {
        _this.props.onClose();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "closeBackdropAndAllDialogs", function () {
      if (_this.props.lock) {
        return;
      }

      _this.setState({
        shouldHideBackdrop: true
      });

      var openedDialog = document.getElementsByClassName("".concat("waui", "-dialog__main_open"))[0];

      if (openedDialog) {
        classlist(openedDialog).remove("".concat("waui", "-dialog__main_open"));

        var onTransitionEnd = function onTransitionEnd() {
          openedDialog.style.display = 'none';
          openedDialog.removeEventListener(ToggleNode.END_EVENT, onTransitionEnd);

          _this.props.onClose();
        };

        openedDialog.addEventListener(ToggleNode.END_EVENT, onTransitionEnd);
      } else {
        _this.props.onClose();
      }
    });

    _this.state = {
      shouldHideBackdrop: false,
      hasExistedBackdrop: !!document.getElementsByClassName("".concat("waui", "-dialog__backdrop"))[0]
    };
    _this.containerNode = document.createElement('div');
    document.body.appendChild(_this.containerNode);
    return _this;
  }

  _createClass(Dialog, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        dialog: this
      };
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      if (!this.dialog) {
        return;
      }

      if (!this.dialogInstance) {
        var dialogNode = ReactDOM.findDOMNode(this.dialog);
        this.dialogInstance = new ToggleNode(dialogNode, "".concat("waui", "-dialog__main_open"));
      }

      this.dialogInstance.open();
      this.props.autoClose && window.setTimeout(function () {
        _this2.close();
      }, this.props.duration);
    }
  }, {
    key: "backUp",
    value: function backUp() {
      var dialogStacks = document.getElementsByClassName("".concat("waui", "-dialog__main"));
      var dialogStacksCount = dialogStacks.length;
      dialogStacksCount > 1 && classlist(dialogStacks[dialogStacksCount - 2]).add("".concat("waui", "-dialog__main_open"));
    }
  }, {
    key: "goForward",
    value: function goForward() {
      var dialogStacks = document.getElementsByClassName("".concat("waui", "-dialog__main"));
      var dialogStacksCount = dialogStacks.length;
      dialogStacksCount > 0 && classlist(dialogStacks[dialogStacksCount - 1]).remove("".concat("waui", "-dialog__main_open"));
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      this.goForward();
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.containerNode && document.body.removeChild(this.containerNode);
      this.state.shouldHideBackdrop || this.props.onClose();
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var _this$state = this.state,
          shouldHideBackdrop = _this$state.shouldHideBackdrop,
          hasExistedBackdrop = _this$state.hasExistedBackdrop;

      var _this$props = this.props,
          backdrop = _this$props.backdrop,
          lock = _this$props.lock,
          type = _this$props.type,
          children = _this$props.children,
          other = _objectWithoutProperties(_this$props, ["backdrop", "lock", "type", "children"]);

      var divProps = omit(other, ['lock', 'autoClose']);
      return createPortal( /*#__PURE__*/React.createElement("div", _extends({
        ref: function ref(dialog) {
          return _this3.dialog = dialog;
        },
        className: cx("".concat("waui", "-dialog__main"), _defineProperty({}, "".concat("waui", "-dialog__main_").concat(type), type))
      }, divProps), !shouldHideBackdrop && !!backdrop && !hasExistedBackdrop && /*#__PURE__*/React.createElement(Backdrop, {
        onClick: this.closeBackdropAndAllDialogs
      }), /*#__PURE__*/React.createElement("div", {
        className: "".concat("waui", "-dialog__main-content")
      }, children)), this.containerNode);
    }
  }]);

  return Dialog;
}(React.Component);

_defineProperty(Dialog, "childContextTypes", {
  dialog: PropTypes.instanceOf(Dialog)
});

_defineProperty(Dialog, "propTypes", {
  backdrop: PropTypes.bool,
  lock: PropTypes.bool,
  autoClose: PropTypes.bool,
  duration: PropTypes.number,
  onClose: PropTypes.func,
  type: PropTypes.oneOf(['aside', 'dialog', 'notification', 'modal'])
});

export default Dialog;
